@@ -434,7 +434,7 @@ def user_change_department(organization_id: int, user_id: int, department_ids: l
     :return:
     """
     if not department_ids:
-        return Resp(code=BadRequestCode, msg=f"department_ids cannot be empty")
+        return Resp(code=BadRequestCode, msg=f"未选择变更部门")
     try:
         valid_department_count = Department.objects.filter(
             id__in=department_ids,
